/*******************************************************
 -------------------------------------------------------
 
|| 文件名称：drv_led.c 
|| 文件概述：RGB LED驱动文件
|| 版 本 号：1.0
|| 编写日期：2021-09-08
|| 编 写 者：Xiao
|| 备    注：IC:CH552  MCLK：32MHz

 -------------------------------------------------------
*******************************************************/



/* 头文件---------------------------------------------------------------------*/
#include "config.h"


/* 本地变量-------------------------------------------------------------------*/

/* 引用变量-------------------------------------------------------------------*/

/* 函数声明-------------------------------------------------------------------*/

/* ---------------------------------------------------------------------------*/





/***********************************************
* 函数名称：__Led_Data_Send
* 功    能：根据对应LED通道，发送8bit数据
* 入口参数：LED_Bank = LED_IO1_BANK 选定通道1
*						LED_Bank = LED_IO2_BANK 选定通道2
*						LED_Bank = LED_IO3_BANK 选定通道3
*
*           dat:所要发送的数据，0~255：代表灰度等级
* 返 回 值：无
* 备    注：重要函数
* 编 写 者：Xiao 2021-09-08
************************************************/ 
/**
  * @brief  发送8bit数据
  * @param  dat 发送的数据
  * @retval null
  */ 
void __led_data_send(unsigned char dat)	
{
  unsigned char i,IO_Level;
  i=8;
	dat<<=1;	
  while(i)	 
  {
    LED_IO = 1;
		
//    #if LED_DRV_MODE
//		IO_Level = CY;
//		#else
//		IO_Level = dat&0x80;
//		#endif
		
		if(CY){
			NOP_Delay(13);
			LED_IO = 0;
			NOP_Delay(14);
		}
		else{
			NOP_Delay(1);
			LED_IO = 0;
			NOP_Delay(13);
			
		}
    dat<<=1;
		i--;
  }     
}



/***********************************************
* 函数名称：__Set_RGB
* 功    能：根据对应LED通道，发送RGB（24bit）数据
* 入口参数：LED_Bank = LED_IO1_BANK 选定通道1
*						LED_Bank = LED_IO2_BANK 选定通道2
*						LED_Bank = LED_IO3_BANK 选定通道3
*
*						Rvalue R灰度值
*						Gvalue G灰度值
*						Bvalue B灰度值
* 返 回 值：无
* 备    注：重要函数
* 编 写 者：Xiao 2021-09-08
************************************************/ 
void __Set_RGB(unsigned char Rvalue, unsigned char Gvalue, unsigned char Bvalue)
{

	EA = 0;		//关闭总中断，保护时序，防止中断影响
   
  __led_data_send(Gvalue);
  __led_data_send(Rvalue);
  __led_data_send(Bvalue);
	
	EA = 1;		//开启总中断
}



/***********************************************
* 函数名称：Turn_Off_LED
* 功    能：关闭对应通道的RGB灯
* 入口参数：LED_Bank = LED_IO1_BANK 选定通道1
*						LED_Bank = LED_IO2_BANK 选定通道2
*						LED_Bank = LED_IO3_BANK 选定通道3
*
*						LED_Number = 所需关闭的led数量
* 返 回 值：无
* 备    注：无
* 编 写 者：Xiao 2021-09-08
************************************************/ 
void Turn_Off_LED(unsigned char LED_Bank, unsigned int LED_Number)
{
	
	switch( LED_Bank ){	//灯数限制
		
		case LED_IO1_BANK :
				if( LED_Number > LED_IO1_NUMBER ) LED_Number = LED_IO1_NUMBER;
				break;
		
		case LED_IO2_BANK :
				if( LED_Number > LED_IO2_NUMBER ) LED_Number = LED_IO2_NUMBER;
				break;
		
		case LED_IO3_BANK :
				if( LED_Number > LED_IO3_NUMBER ) LED_Number = LED_IO3_NUMBER;
				break;		
	}
	
	while( LED_Number > 0 ){
					
		__Set_RGB( 0, 0, 0);
					
		LED_Number--;
	}
	
}



/***********************************************
* 函数名称：Init_Drv_Led
* 功    能：灯带DI口初始化
* 入口参数：无
* 返 回 值：无
* 备    注：无
* 编 写 者：Xiao 2021-09-08
************************************************/ 
void Init_Drv_Led(void)
{
	P3_MOD_OC &= 0xF8;		//0000 0000  
	P3_DIR_PU |= 0x07;		//0000 0111  P3.0 P3.1 P3.2信号输出(推挽输出)

	LED_IO = 0;
	LED_IO2 = 0;
	LED_IO3 = 0;
	
	mDelayuS(LED_RESET_TIME);
}

/* END------------------------------------------------------------------------*/

